@@ -348,21 +348,21 @@ function form_actions() {
 				<p>" . __('Click \'Continue\' to delete the following Network(s).') . "</p>
 				<div class='itemlist'><ul>$networks_list</ul></div>
 			</td>
-		</tr>\n";
+		</tr>";
 	} elseif (get_nfilter_request_var('drp_action') == '3') { /* enable */
 		print "<tr>
 			<td class='textArea'>
 				<p>" . __('Click \'Continue\' to enable the following Network(s).') . "</p>
 				<div class='itemlist'><ul>$networks_list</ul></div>
 			</td>
-		</tr>\n";
+		</tr>";
 	} elseif (get_nfilter_request_var('drp_action') == '2') { /* disable */
 		print "<tr>
 			<td class='textArea'>
 				<p>" . __('Click \'Continue\' to disable the following Network(s).') . "</p>
 				<div class='itemlist'><ul>$networks_list</ul></div>
 			</td>
-		</tr>\n";
+		</tr>";
 	} elseif (get_nfilter_request_var('drp_action') == '4') { /* discover now */
 		print "<tr>
 			<td class='textArea'>
@@ -371,14 +371,14 @@ function form_actions() {
 				<p><input type='checkbox' id='discover_debug' name='discover_debug' value='1'>
 				<label id='discover_debug_label' for='discover_debug'>" . __('Run discover in debug mode') . "</label></p>
 			</td>
-		</tr>\n";
+		</tr>";
 	} elseif (get_nfilter_request_var('drp_action') == '5') { /* cancel discovery now */
 		print "<tr>
 			<td class='textArea'>
 				<p>" . __('Click \'Continue\' to cancel on going Network Discovery(s).') . "</p>
 				<div class='itemlist'><ul>$networks_list</ul></div>
 			</td>
-		</tr>\n";
+		</tr>";
 	}
 
 	if (!isset($networks_array)) {
@@ -397,7 +397,7 @@ function form_actions() {
 			<input type='submit' class='ui-button ui-corner-all ui-widget' name='cancel' value='" . __esc('Cancel') . "'>
 			$save_html" : "<input type='submit' class='ui-button ui-corner-all ui-widget' name='cancel' value='" . __esc('Return') . "'>") . "
 		</td>
-	</tr>\n";
+	</tr>";
 
 	html_end_box();
 
@@ -786,9 +786,9 @@ function network_edit() {
 			noneSelectedText: '<?php print __('Select the days(s) of the week');?>',
 			header: false,
 			height: 54,
-			multipleRow: true,
-			multipleRowWidth: 90,
-			minWidth: 450
+			groupColumns: true,
+			groupColumnsWidth: 90,
+			menuWidth: 385
 		});
 
 		$('#month').multiselect({
@@ -796,9 +796,9 @@ function network_edit() {
 			noneSelectedText: '<?php print __('Select the month(s) of the year');?>',
 			header: false,
 			height: 82,
-			multipleRow: true,
-			multipleRowWidth: 90,
-			minWidth: 400
+			groupColumns: true,
+			groupColumnsWidth: 90,
+			menuWidth: 380
 		});
 
 		$('#day_of_month').multiselect({
@@ -806,9 +806,9 @@ function network_edit() {
 			noneSelectedText: '<?php print __('Select the day(s) of the month');?>',
 			header: false,
 			height: 162,
-			multipleRow: true,
-			multipleRowWidth: 55,
-			minWidth: 400
+			groupColumns: true,
+			groupColumnsWidth: 50,
+			menuWidth: 275
 		});
 
 		$('#monthly_week').multiselect({
@@ -816,9 +816,9 @@ function network_edit() {
 			noneSelectedText: '<?php print __('Select the week(s) of the month');?>',
 			header: false,
 			height: 28,
-			multipleRow: true,
-			multipleRowWidth: 70,
-			minWidth: 300
+			groupColumns: true,
+			groupColumnsWidth: 70,
+			menuWidth: 300
 		});
 
 		$('#monthly_day').multiselect({
@@ -826,9 +826,9 @@ function network_edit() {
 			noneSelectedText: '<?php print __('Select the day(s) of the week');?>',
 			header: false,
 			height: 54,
-			multipleRow: true,
-			multipleRowWidth: 90,
-			minWidth: 450
+			groupColumns: true,
+			groupColumnsWidth: 90,
+			menuWidth: 385
 		});
 
 		$('#start_at').datetimepicker({
@@ -968,7 +968,7 @@ function network_edit() {
 
 function get_networks(&$sql_where, $rows, $apply_limits = true) {
 	if (get_request_var('filter') != '') {
-		$sql_where = " WHERE (automation_networks.name LIKE '%" . get_request_var('filter') . "%')";
+		$sql_where = ' WHERE (automation_networks.name LIKE ' . db_qstr('%' . get_request_var('filter') . '%') . ')';
 	}
 
 	$sql_order = get_order_string();
@@ -1009,10 +1009,9 @@ function networks() {
 			'default' => '20'
 			),
 		'filter' => array(
-			'filter' => FILTER_CALLBACK,
+			'filter' => FILTER_DEFAULT,
 			'pageset' => true,
-			'default' => '',
-			'options' => array('options' => 'sanitize_search_string')
+			'default' => ''
 			),
 		'sort_column' => array(
 			'filter' => FILTER_CALLBACK,
@@ -1185,7 +1184,7 @@ function networks_filter() {
 							<?php
 							if (cacti_sizeof($item_rows)) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . $value . "</option>\n";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . $value . "</option>";
 								}
 							}
 							?>
