@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -109,7 +109,6 @@ $orig_cacti_version = get_cacti_version();
 
 // loop through versions from old version to the current, performing updates for each version in the chain
 foreach ($cacti_version_codes as $cacti_upgrade_version => $hash_code)  {
-
 	// skip versions old than the database version
 	if (cacti_version_compare($old_cacti_version, $cacti_upgrade_version, '>=')) {
 		continue;
@@ -135,7 +134,6 @@ foreach ($cacti_version_codes as $cacti_upgrade_version => $hash_code)  {
 			break;
 		}
 
-		print "\n";
 		if (cacti_version_compare($orig_cacti_version, $cacti_upgrade_version, '<')) {
 			db_execute("UPDATE version SET cacti = '" . $cacti_upgrade_version . "'");
 			$orig_cacti_version = $cacti_upgrade_version;
@@ -143,6 +141,8 @@ foreach ($cacti_version_codes as $cacti_upgrade_version => $hash_code)  {
 		$prev_cacti_version = $cacti_upgrade_version;
 	}
 
+	db_execute("UPDATE version SET cacti = '" . $cacti_upgrade_version . "'");
+
 	if (CACTI_VERSION == $cacti_upgrade_version) {
 		break;
 	}
