@@ -999,7 +999,7 @@ function form_actions() {
 
 				if (cacti_sizeof($data_sources)) {
 					print "<td class='textArea'>" .
-					'<p>' . __('The following data sources are in use by these graphs:') . '</p>
+					'<p>' . __('The following Data Sources are in use by these Graphs:') . '</p>
 					<div class="itemlist"><ul>';
 					foreach ($data_sources as $data_source) {
 						print '<li>' . html_escape($data_source['name_cache']) . '</li>';
@@ -1040,19 +1040,56 @@ function form_actions() {
 					switch ($('#aggregate_total').val()) {
 						case '<?php print AGGREGATE_TOTAL_NONE;?>':
 							$('#aggregate_total_type').prop('disabled', true);
+							if ($('#aggregate_total_type').selectmenu('instance')) {
+								$('#aggregate_total_type').selectmenu('disable');
+							}
+
 							$('#aggregate_total_prefix').prop('disabled', true);
+							if ($('#aggregate_total_prefix').selectmenu('instance')) {
+								$('#aggregate_total_prefix').selectmenu('disable');
+							}
+
 							$('#aggregate_order_type').prop('disabled', false);
+							if ($('#aggregate_order_type').selectmenu('instance')) {
+								$('#aggregate_order_type').selectmenu('enable');
+							}
+
 							break;
 						case '<?php print AGGREGATE_TOTAL_ALL;?>':
 							$('#aggregate_total_type').prop('disabled', false);
+							if ($('#aggregate_total_type').selectmenu('instance')) {
+								$('#aggregate_total_type').selectmenu('enable');
+							}
+
 							$('#aggregate_total_prefix').prop('disabled', false);
+							if ($('#aggregate_total_prefix').selectmenu('instance')) {
+								$('#aggregate_total_prefix').selectmenu('enable');
+							}
+
+
 							$('#aggregate_order_type').prop('disabled', false);
+							if ($('#aggregate_order_type').selectmenu('instance')) {
+								$('#aggregate_order_type').selectmenu('enable');
+							}
+
+
 							changeTotalsType();
 							break;
 						case '<?php print AGGREGATE_TOTAL_ONLY;?>':
 							$('#aggregate_total_type').prop('disabled', false);
+							if ($('#aggregate_total_type').selectmenu('instance')) {
+								$('#aggregate_total_type').selectmenu('enable');
+							}
 							$('#aggregate_total_prefix').prop('disabled', false);
+							if ($('#aggregate_total_prefix').selectmenu('instance')) {
+								$('#aggregate_total_prefix').selectmenu('enable');
+							}
+
 							$('#aggregate_order_type').prop('disabled', true);
+							if ($('#aggregate_order_type').selectmenu('instance')) {
+								$('#aggregate_order_type').selectmenu('disable');
+							}
+
 							changeTotalsType();
 							break;
 					}
@@ -1066,6 +1103,14 @@ function form_actions() {
 					}
 				}
 
+				function checkSubmit() {
+					if ($('input[id^="agg_total"]:checked').length == 0) {
+						$('input[type="submit"]').prop('disable', true).addClass('ui-state-disabled');;
+					} else {
+						$('input[type="submit"]').prop('disable', true).removeClass('ui-state-disabled');;
+					}
+				}
+
 				$(function() {
 					$('#aggregate_total').change(function() {
 						changeTotals();
@@ -1089,6 +1134,8 @@ function form_actions() {
 						} else {
 							$('#'+altId).prop('checked', true);
 						}
+
+						checkSubmit();
 					});
 
 					$('input[id^="agg_skip"]').each(function() {
@@ -1096,11 +1143,12 @@ function form_actions() {
 					});
 
 					changeTotals();
+					checkSubmit();
 				});
 				</script>
 				<?php
 
-				$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Resize Selected Graph(s)') . "'>";
+				$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Create Aggregate Graph') . "'>";
 			} else {
 				$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 			}
@@ -1143,7 +1191,7 @@ function form_actions() {
 						</td>
 					</tr></table></td></tr>\n";
 
-					$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Create Aggregate') . "'>";
+					$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Create Aggregate from Template') . "'>";
 				} else {
 					print "<tr>
 						<td class='textArea'>
@@ -1324,14 +1372,14 @@ function graph_edit() {
 			WHERE local_graph_id = ?',
 			array(get_request_var('id')));
 
-	        $auto_unlock = read_config_option('graphs_auto_unlock');
+		$auto_unlock = read_config_option('graphs_auto_unlock');
 
 		if (get_request_var('id') != $_SESSION['sess_graph_lock_id'] && !empty($local_graph_template_graph_id)) {
 			if ($auto_unlock == 'on') {
-                        	$locked = false;
-                        } else {
-	                        $locked = true;
-                        }
+				$locked = false;
+			} else {
+				$locked = true;
+			}
 			$_SESSION['sess_graph_locked'] = $locked;
 		} elseif (empty($local_graph_template_graph_id)) {
 			$locked = false;
@@ -1488,6 +1536,17 @@ function graph_edit() {
 			)
 		);
 
+	if (cacti_sizeof($graph)) {
+		if ($graph['graph_template_id'] == 0) {
+			$form_array['graph_template_id']['method'] = 'hidden';
+		}
+
+		if ($graph['graph_template_id'] > 0 && $host_id > 0) {
+			$form_array['graph_template_id']['method'] = 'hidden';
+			$form_array['host_id']['method'] = 'hidden';
+		}
+	}
+
 	draw_edit_form(
 		array(
 			'config' => array('no_form_tag' => true),
