@@ -940,6 +940,7 @@ function utilities_get_mysql_recommendations() {
 		'innodb_file_per_table' => array(
 			'value'   => 'ON',
 			'measure' => 'equalint',
+			'class'   => 'error',
 			'comment' => __('When using InnoDB storage it is important to keep your table spaces separate.  This makes managing the tables simpler for long time users of %s.  If you are running with this currently off, you can migrate to the per file storage by enabling the feature, and then running an alter statement on all InnoDB tables.', $database)
 			),
 		'innodb_file_format' => array(
@@ -961,10 +962,10 @@ function utilities_get_mysql_recommendations() {
 			'comment' => __('InnoDB will hold as much tables and indexes in system memory as is possible.  Therefore, you should make the innodb_buffer_pool large enough to hold as much of the tables and index in memory.  Checking the size of the /var/lib/mysql/cacti directory will help in determining this value.  We are recommending 25%% of your systems total memory, but your requirements will vary depending on your systems size.')
 			),
 		'innodb_doublewrite' => array(
-			'value'   => 'OFF',
+			'value'   => 'ON',
 			'measure' => 'equalint',
-			'class' => 'warning',
-			'comment' => __('With modern SSD type storage, this operation actually degrades the disk more rapidly and adds a 50%% overhead on all write operations.')
+			'class' => 'error',
+			'comment' => __('This settings should remain ON unless your Cacti instances is running on either ZFS or FusionI/O which both have internal journaling to accomodate abrupt system crashes.  However, if you have very good power, and your systems rarely go down and you have backups, turning this setting to OFF can net you almost a 50% increase in database performance.')
 			),
 		'innodb_additional_mem_pool_size' => array(
 			'value'   => '80M',
@@ -1435,17 +1436,19 @@ function utility_php_verify_recommends(&$recommends, $source) {
 }
 
 function utility_php_set_recommends_text(&$recs) {
-	foreach ($recs as $name => $recommends) {
-		if (sizeof($recommends)) {
-			foreach ($recommends as $index => $recommend) {
-				if ($recommend['name'] == 'version') {
-					$recs[$name][$index]['description'] = __('PHP %s is the mimimum version', $recommend['value']);
-				} elseif ($recommend['name'] == 'memory_limit') {
-					$recs[$name][$index]['description'] = __('A minimum of %s MB memory limit', $recommend['value']);
-				} elseif ($recommend['name'] == 'max_execution_time') {
-					$recs[$name][$index]['description'] = __('A minimum of %s m execution time', $recommend['value']);
-				} elseif ($recommend['name'] == 'date.timezone') {
-					$recs[$name][$index]['description'] = __('A valid timezone that matches MySQL and the system');
+	if (is_array($recs) && sizeof($recs)) {
+		foreach ($recs as $name => $recommends) {
+			if (cacti_sizeof($recommends)) {
+				foreach ($recommends as $index => $recommend) {
+					if ($recommend['name'] == 'version') {
+						$recs[$name][$index]['description'] = __('PHP %s is the mimimum version', $recommend['value']);
+					} elseif ($recommend['name'] == 'memory_limit') {
+						$recs[$name][$index]['description'] = __('A minimum of %s MB memory limit', $recommend['value']);
+					} elseif ($recommend['name'] == 'max_execution_time') {
+						$recs[$name][$index]['description'] = __('A minimum of %s m execution time', $recommend['value']);
+					} elseif ($recommend['name'] == 'date.timezone') {
+						$recs[$name][$index]['description'] = __('A valid timezone that matches MySQL and the system');
+					}
 				}
 			}
 		}
